# 1.0.1 (2025 - 10 - 20)

Drop support for `python3.9`

* Rename `qaoa` install flag to `dqo`

# 1.0.0 (2025 - 05 - 13)

Initial public release.

### Features

* Added `tno.quantum.optimization.qubo.components==1.0.0`
* Added `tno.quantum.optimization.qubo.preprocessors==1.0.0`
* Added `tno.quantum.optimization.qubo.solvers==1.0.0`
* Added `tno.quantum.optimization.qubo.postprocessors==1.0.0`